@@ -1,12 +1,13 @@
 package CHI;
-BEGIN {
-  $CHI::VERSION = '0.56';
-}    ## no critic (Moose::RequireMakeImmutable)
+{
+  $CHI::VERSION = '0.58';
+}
 use 5.006;
 use Carp;
 use CHI::Stats;
-use Moose;
 use String::RewritePrefix;
+use Module::Runtime qw(require_module);
+use Moo::Role ();
 use strict;
 use warnings;
 
@@ -30,10 +31,13 @@ sub _set_config {
     if ( my @bad_keys = grep { !$valid_config_keys{$_} } keys(%$config) ) {
         croak "unknown keys in config hash: " . join( ", ", @bad_keys );
     }
-    $class->meta->add_method( '_get_config' => sub { $config } );
+    # set class specific configuration
+    no strict 'refs';
+    no warnings 'redefine';
+    *{"$class\::_get_config"} = sub { $config };
 }
 
-CHI->config( {} );
+BEGIN { __PACKAGE__->config( {} ) }
 
 sub memoized_cache_objects {
     my ($class) = @_;
@@ -114,7 +118,7 @@ sub new {
     # Load driver class if it hasn't been loaded or defined in-line already
     #
     unless ( $driver_class->can('fetch') ) {
-        Class::MOP::load_class($driver_class);
+        require_module($driver_class);
     }
 
     # Select roles depending on presence of certain arguments. Everyone gets
@@ -123,8 +127,8 @@ sub new {
     #
     my @roles = ('Universal');
     foreach my $param_name (qw(roles traits)) {
-        if ( exists( $params{param_name} ) ) {
-            push( @roles, @{ delete( $params{param_name} ) } );
+        if ( exists( $params{$param_name} ) ) {
+            push( @roles, @{ delete( $params{$param_name} ) } );
         }
     }
     if ( exists( $params{max_size} ) || exists( $params{is_size_aware} ) ) {
@@ -142,17 +146,8 @@ sub new {
     # Select a final class based on the driver class and roles, creating it
     # if necessary - adapted from MooseX::Traits
     #
-    my $meta = Moose::Meta::Class->create_anon_class(
-        superclasses => [$driver_class],
-        roles        => \@roles,
-        cache        => 1
-    );
-    my $final_class = $meta->name;
-    $meta->add_method( 'meta' => sub { $meta } )
-      if !$final_class_seen{$final_class}++;
+    my $final_class = Moo::Role->create_class_with_roles($driver_class, @roles);
 
-    # Finally create the object
-    #
     my $cache_object = $final_class->new(
         chi_root_class => $chi_root_class,
         driver_class   => $driver_class,
@@ -170,7 +165,7 @@ sub new {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -180,7 +175,7 @@ CHI - Unified cache handling interface
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -506,8 +501,8 @@ L</expires_variance> for another technique.
 
 =item obj_ref [SCALARREF]
 
-If the item exists in cache, place the <CHI::CacheObject|CHI::CacheObject>
-object in the provided SCALARREF.
+If the item exists in cache (even if expired), place the
+L<CHI::CacheObject|CHI::CacheObject> object in the provided SCALARREF.
 
 =back
 
@@ -1552,7 +1547,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
