@@ -1,9 +1,8 @@
 package CHI::Driver::Base::CacheContainer;
-BEGIN {
-  $CHI::Driver::Base::CacheContainer::VERSION = '0.56';
+{
+  $CHI::Driver::Base::CacheContainer::VERSION = '0.58';
 }
-use Moose;
-use Moose::Util::TypeConstraints;
+use Moo;
 use List::MoreUtils qw( all );
 use strict;
 use warnings;
@@ -12,8 +11,6 @@ extends 'CHI::Driver';
 
 has '_contained_cache' => ( is => 'ro' );
 
-__PACKAGE__->meta->make_immutable();
-
 sub fetch {
     my ( $self, $key ) = @_;
 
@@ -52,7 +49,7 @@ sub get_namespaces {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -62,7 +59,7 @@ CHI::Driver::Base::CacheContainer - Caches that delegate to a contained cache
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 DESCRIPTION
 
@@ -85,7 +82,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
