@@ -1,22 +1,21 @@
 package CHI::Driver::FastMmap;
-BEGIN {
-  $CHI::Driver::FastMmap::VERSION = '0.56';
+{
+  $CHI::Driver::FastMmap::VERSION = '0.58';
 }
 use Carp;
 use Cache::FastMmap;
 use CHI::Util qw(read_dir);
 use File::Path qw(mkpath);
 use File::Spec::Functions qw(catdir catfile splitdir tmpdir);
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 use strict;
 use warnings;
 
 extends 'CHI::Driver::Base::CacheContainer';
 
-has 'dir_create_mode' => ( is => 'ro', isa => 'Int', default => oct(775) );
-has 'root_dir'        => ( is => 'ro', isa => 'Str', default => catdir( tmpdir(), "chi-driver-fastmmap" ) );
-
-__PACKAGE__->meta->make_immutable();
+has 'dir_create_mode' => ( is => 'ro', isa => Int, default => sub { oct(775) } );
+has 'root_dir'        => ( is => 'ro', isa => Str, default => sub { catdir( tmpdir(), "chi-driver-fastmmap" ) } );
 
 sub BUILD {
     my ( $self, $params ) = @_;
@@ -79,7 +78,7 @@ sub store {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -89,7 +88,7 @@ CHI::Driver::FastMmap - Persistent interprocess cache via mmap'ed files
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -167,7 +166,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
