@@ -1,10 +1,9 @@
 package CHI::Driver::File;
-BEGIN {
-  $CHI::Driver::File::VERSION = '0.56';
+{
+  $CHI::Driver::File::VERSION = '0.58';
 }
 use Carp;
 use Cwd qw(realpath cwd);
-use CHI::Types;
 use CHI::Util
   qw(fast_catdir fast_catfile unique_id read_dir read_file write_file);
 use Digest::JHash qw(jhash);
@@ -13,21 +12,20 @@ use File::Find qw(find);
 use File::Path qw(mkpath rmtree);
 use File::Spec::Functions qw(catdir catfile splitdir tmpdir);
 use Log::Any qw($log);
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 use strict;
 use warnings;
 
 extends 'CHI::Driver';
 
-has '+max_key_length'   => ( default => 248 );
-has 'depth'             => ( is => 'ro', isa => 'Int', default => 2 );
-has 'dir_create_mode'   => ( is => 'ro', isa => 'Int', default => oct(775) );
-has 'file_create_mode'  => ( is => 'ro', isa => 'Int', default => oct(666) );
-has 'file_extension'    => ( is => 'ro', isa => 'Str', default => '.dat' );
-has 'path_to_namespace' => ( is => 'ro', lazy => 1, builder => '_build_path_to_namespace' );
-has 'root_dir'          => ( is => 'ro', isa => 'Str', default => catdir( tmpdir(), 'chi-driver-file' ) );
-
-__PACKAGE__->meta->make_immutable();
+has '+max_key_length'   => ( default => sub { 248 } );
+has 'depth'             => ( is => 'ro', isa => Int, default => sub { 2 } );
+has 'dir_create_mode'   => ( is => 'ro', isa => Int, default => sub { oct(775) } );
+has 'file_create_mode'  => ( is => 'ro', isa => Int, default => sub { oct(666) } );
+has 'file_extension'    => ( is => 'ro', isa => Str, default => sub { '.dat' } );
+has 'path_to_namespace' => ( is => 'lazy' );
+has 'root_dir'          => ( is => 'ro', isa => Str, default => sub { catdir( tmpdir(), 'chi-driver-file' ) } );
 
 sub BUILDARGS {
     my ( $class, %params ) = @_;
@@ -239,7 +237,7 @@ sub path_to_key {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -250,7 +248,7 @@ directory structure
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -361,7 +359,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
