@@ -1,10 +1,11 @@
 package CHI::Driver::Memory;
-BEGIN {
-  $CHI::Driver::Memory::VERSION = '0.56';
+{
+  $CHI::Driver::Memory::VERSION = '0.58';
 }
 use Carp qw(cluck croak);
 use CHI::Constants qw(CHI_Meta_Namespace);
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 use strict;
 use warnings;
 
@@ -12,10 +13,8 @@ extends 'CHI::Driver';
 
 our %Global_Datastore = ();    ## no critic (ProhibitPackageVars)
 
-has 'datastore' => ( is => 'ro', isa => 'HashRef' );
-has 'global'    => ( is => 'ro', isa => 'Bool' );
-
-__PACKAGE__->meta->make_immutable();
+has 'datastore' => ( is => 'ro', isa => HashRef );
+has 'global'    => ( is => 'ro', isa => Bool );
 
 sub default_discard_policy { 'lru' }
 
@@ -95,7 +94,7 @@ sub discard_policy_lru {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -105,7 +104,7 @@ CHI::Driver::Memory - In-process memory based cache
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -154,7 +153,7 @@ unrelated code).
 
 =head1 DISCARD POLICY
 
-For L<CHI/SIZE AWARENESS|size aware> caches, this driver implements an 'LRU'
+For L<size aware|CHI/SIZE AWARENESS> caches, this driver implements an 'LRU'
 policy, which discards the least recently used items first. This is the default
 policy.
 
@@ -174,7 +173,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
