@@ -1,13 +1,12 @@
 package CHI::Driver::Null;
-BEGIN {
-  $CHI::Driver::Null::VERSION = '0.56';
+{
+  $CHI::Driver::Null::VERSION = '0.58';
 }
-use Moose;
+use Moo;
 use strict;
 use warnings;
 
 extends 'CHI::Driver';
-__PACKAGE__->meta->make_immutable();
 
 sub fetch          { undef }
 sub store          { undef }
@@ -18,7 +17,7 @@ sub get_namespaces { return () }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -28,7 +27,7 @@ CHI::Driver::Null - Nothing is cached
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -59,7 +58,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
