@@ -1,14 +1,14 @@
 package CHI::Driver::RawMemory;
-BEGIN {
-  $CHI::Driver::RawMemory::VERSION = '0.56';
+{
+  $CHI::Driver::RawMemory::VERSION = '0.58';
 }
-use Moose;
+use Moo;
 use strict;
 use warnings;
 
 extends 'CHI::Driver::Memory';
 
-has 'serializer' => ( is => 'ro', default => undef, init_arg => undef );
+has 'serializer' => ( is => 'ro', init_arg => undef );
 
 sub append {
     my ( $self, $key, $new ) = @_;
@@ -16,11 +16,9 @@ sub append {
     return "append not yet supported in this driver";
 }
 
-__PACKAGE__->meta->make_immutable();
-
 1;
 
-
+__END__
 
 =pod
 
@@ -30,7 +28,7 @@ CHI::Driver::RawMemory - In-process memory cache that stores direct references
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -97,7 +95,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
