@@ -1,8 +1,8 @@
 package CHI::Driver::Role::IsSubcache;
-BEGIN {
-  $CHI::Driver::Role::IsSubcache::VERSION = '0.56';
+{
+  $CHI::Driver::Role::IsSubcache::VERSION = '0.58';
 }
-use Moose::Role;
+use Moo::Role;
 use strict;
 use warnings;
 
