@@ -2,16 +2,14 @@
 # Recommend Data::Serializer for other serializers, rather than reinventing the wheel.
 #
 package CHI::Serializer::JSON;
-BEGIN {
-  $CHI::Serializer::JSON::VERSION = '0.56';
+{
+  $CHI::Serializer::JSON::VERSION = '0.58';
 }
 use CHI::Util qw(json_encode json_decode);
-use Moose;
+use Moo;
 use strict;
 use warnings;
 
-__PACKAGE__->meta->make_immutable;
-
 sub serialize {
     return json_encode( $_[1] );
 }
