@@ -1,23 +1,21 @@
 package CHI::Stats;
-BEGIN {
-  $CHI::Stats::VERSION = '0.56';
+{
+  $CHI::Stats::VERSION = '0.58';
 }
 use CHI::Util qw(json_encode json_decode);
 use List::Util qw(sum);
 use Log::Any qw($log);
-use Moose;
+use Moo;
 use strict;
 use warnings;
 
 has 'chi_root_class' => ( is => 'ro' );
 has 'data'           => ( is => 'ro', default => sub { {} } );
-has 'enabled'        => ( is => 'ro', default => 0 );
+has 'enabled'        => ( is => 'rwp', default => sub { 0 } );
 has 'start_time'     => ( is => 'ro', default => sub { time } );
 
-__PACKAGE__->meta->make_immutable();
-
-sub enable  { $_[0]->{enabled} = 1 }
-sub disable { $_[0]->{enabled} = 0 }
+sub enable  { $_[0]->_set_enabled(1) }
+sub disable { $_[0]->_set_enabled(0) }
 
 sub flush {
     my ($self) = @_;
@@ -157,7 +155,7 @@ sub clear {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -167,7 +165,7 @@ CHI::Stats - Record and report per-namespace cache statistics
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -377,7 +375,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
