@@ -1,13 +1,12 @@
 package CHI::Test::Driver::Readonly;
-BEGIN {
-  $CHI::Test::Driver::Readonly::VERSION = '0.56';
+{
+  $CHI::Test::Driver::Readonly::VERSION = '0.58';
 }
 use Carp;
-use Moose;
+use Moo;
 use strict;
 use warnings;
 extends 'CHI::Driver::Memory';
-__PACKAGE__->meta->make_immutable();
 
 sub store {
     my ( $self, $key, $data ) = @_;
