@@ -1,9 +1,9 @@
 package CHI::Test::Driver::Role::CheckKeyValidity;
-BEGIN {
-  $CHI::Test::Driver::Role::CheckKeyValidity::VERSION = '0.56';
+{
+  $CHI::Test::Driver::Role::CheckKeyValidity::VERSION = '0.58';
 }
 use Carp;
-use Moose::Role;
+use Moo::Role;
 use strict;
 use warnings;
 
