@@ -1,6 +1,6 @@
 package CHI::t::Driver;
-BEGIN {
-  $CHI::t::Driver::VERSION = '0.56';
+{
+  $CHI::t::Driver::VERSION = '0.58';
 }
 use strict;
 use warnings;
@@ -586,8 +586,8 @@ sub test_serialize : Tests {
 
 {
     package DummySerializer;
-BEGIN {
-  $DummySerializer::VERSION = '0.56';
+{
+  $DummySerializer::VERSION = '0.58';
 }
     sub serialize   { }
     sub deserialize { }
@@ -621,7 +621,7 @@ sub test_serializers : Tests {
         sub {
             $self->new_cache( serializer => [1] );
         },
-        qr/Validation failed for/,
+        qr/Validation failed for|isa check for ".*?" failed/,
         "invalid serializer"
     );
     lives_ok(
@@ -1707,7 +1707,13 @@ sub test_no_leak : Tests {
     ok( !defined($weakref), "weakref is no longer defined - cache was freed" );
 }
 
-Class::MOP::Class->create( 'My::CHI' => ( superclasses => ['CHI'] ) );
+{
+  package My::CHI;
+{
+  $My::CHI::VERSION = '0.58';
+}
+  our @ISA = qw(CHI);
+}
 
 sub test_driver_properties : Tests {
     my $self  = shift;
