@@ -1,6 +1,6 @@
 package CHI::t::Driver::File;
-BEGIN {
-  $CHI::t::Driver::File::VERSION = '0.56';
+{
+  $CHI::t::Driver::File::VERSION = '0.58';
 }
 use strict;
 use warnings;
@@ -23,12 +23,11 @@ sub new_cache_options {
 
 {
     package CHI::t::Driver::File::NoTempDriver;
-BEGIN {
-  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.56';
+{
+  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.58';
 }
-    use Moose;
+    use Moo;
     extends 'CHI::Driver::File';
-    __PACKAGE__->meta->make_immutable;
 
     sub generate_temporary_filename {
         my ( $self, $dir, $file ) = @_;
@@ -38,12 +37,11 @@ BEGIN {
 
 {
     package CHI::t::Driver::File::BadTempDriver;
-BEGIN {
-  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.56';
+{
+  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.58';
 }
-    use Moose;
+    use Moo;
     extends 'CHI::Driver::File';
-    __PACKAGE__->meta->make_immutable;
 
     sub generate_temporary_filename {
         my ( $self, $dir, $file ) = @_;
