@@ -1,6 +1,6 @@
 package CHI::t::GetError;
-BEGIN {
-  $CHI::t::GetError::VERSION = '0.56';
+{
+  $CHI::t::GetError::VERSION = '0.58';
 }
 use strict;
 use warnings;
@@ -58,7 +58,7 @@ sub test_get_errors : Tests {
 
     throws_ok(
         sub { writeonly_cache('bad') },
-        qr/Attribute .* does not pass the type constraint/,
+        qr/Validation failed for|isa check for .* failed/,
         "bad - dies"
     );
 }
