@@ -1,6 +1,6 @@
 package CHI::t::SetError;
-BEGIN {
-  $CHI::t::SetError::VERSION = '0.56';
+{
+  $CHI::t::SetError::VERSION = '0.58';
 }
 use strict;
 use warnings;
@@ -57,7 +57,7 @@ sub test_set_errors : Tests {
 
     throws_ok(
         sub { readonly_cache('bad') },
-        qr/Attribute .* does not pass the type constraint/,
+        qr/Validation failed for|isa check for ".*" failed/,
         "bad - dies"
     );
 }
