@@ -1,6 +1,6 @@
 package CHI::t::Subcache;
-BEGIN {
-  $CHI::t::Subcache::VERSION = '0.56';
+{
+  $CHI::t::Subcache::VERSION = '0.58';
 }
 use CHI::Test;
 use CHI::Util qw(can_load);
@@ -44,7 +44,7 @@ sub test_bad_subcache_option : Tests {
                 l1_cache => CHI->new( driver => 'Memory', global => 1 )
             );
         },
-        qr/Validation failed/,
+        qr/Validation failed for|isa check for .*? failed/,
         'cannot pass cache object as subcache'
     );
 }
