@@ -1,6 +1,6 @@
 package CHI::t::Subclass;
-BEGIN {
-  $CHI::t::Subclass::VERSION = '0.56';
+{
+  $CHI::t::Subclass::VERSION = '0.58';
 }
 use strict;
 use warnings;
@@ -11,13 +11,12 @@ use base qw(CHI::Test::Class);
 #
 {
     package CHI::t::Subclass::Driver::HasUnsupported;
-BEGIN {
-  $CHI::t::Subclass::Driver::HasUnsupported::VERSION = '0.56';
+{
+  $CHI::t::Subclass::Driver::HasUnsupported::VERSION = '0.58';
 }
-    use Moose;
+    use Moo;
     extends 'CHI::Driver::Memory';
     __PACKAGE__->declare_unsupported_methods(qw(get_namespaces));
-    __PACKAGE__->meta->make_immutable;
 }
 
 sub test_unsupported : Tests {
